@@ -232,8 +232,9 @@ fn main() {
         use pyo3::conversion::ToPyObject;
         use roqoqo::operations::*;
         use std::collections::HashMap;
-        use ndarray::{Array1, Array};
+        use ndarray::Array1;
         use num_complex::Complex64;
+        use numpy::PyArray2;
 
         /// Tries to convert a [roqoqo::operations::Operation] to a PyObject
         pub fn convert_operation_to_pyobject(operation: Operation) -> PyResult<PyObject> {
